<?php

namespace Drp\SimpleCms\Http\Controllers\Admin;

use Drp\SimpleCms\Contracts\ContentFactory;
use Drp\SimpleCms\Exceptions\CouldNotResetDraft;
use Illuminate\Foundation\Auth\Access\AuthorizesRequests;
use Illuminate\Http\RedirectResponse;
use Illuminate\Routing\Controller;

class ResetController extends Controller
{
    use AuthorizesRequests;

    /**
     * @var ContentFactory
     */
    private $contentFactory;

    public function __construct(ContentFactory $contentFactory)
    {
        $this->contentFactory = $contentFactory;
    }

    public function __invoke(string $contentType, int $versionId): RedirectResponse
    {
        $content = $this->contentFactory->byTypeAndVersionId($contentType, $versionId);

        try {
            $this->authorize('publish', $content);
            $content->resetDraft();
            flash()->success(trans('simpleCms::content.was-reset'));
        } catch (CouldNotResetDraft $e) {
            flash()->error(trans('simpleCms::content.not-reset'));
        }
        return redirect()->back();
    }
}
