<?php

namespace Drp\SimpleCms\ViewComposers;

use Illuminate\Support\Collection;
use Illuminate\View\View;

class PreviewModeComposer
{
    public function compose(View $view): void
    {
        $view->with('contentInPreview', $this->contentInPreview($view))
            ->with('userCanEdit', auth()->user()->hasPublishAccess());
    }

    protected function getContent(View $view): Collection
    {
        // phpcs:disable Generic.CodeAnalysis.UnusedFunctionParameter.Found
        $contentTypes = collect(config('simple_cms.content_types'))
            ->map(function ($class, $key) {
                return camel_case($key);
            })->flip();

        return collect($view->getData())
            ->intersectKey($contentTypes);
        // phpcs:enable Generic.CodeAnalysis.UnusedFunctionParameter.Found
    }

    protected function contentInPreview(View $view): Collection
    {
        $urlKey = $this->getKeyFromUrl();

        return $this->getContent($view)
            ->flatten()
            ->filter()
            ->filter(function ($item) use ($view, $urlKey) {
                return $item->isDraftOrInReview($urlKey);
            });
    }

    /**
     * Return the correct study key from the url.
     * If the url segment is not a study key then look in the mappings config.
     * If the url segment is still not found then this is the nameplate home page.
     *
     * @return mixed|string
     */
    private function getKeyFromUrl()
    {
        $urlKey = collect(request()->segments())->last();

        return str_replace('-', '_', $urlKey);
    }
}
